@@ -1,3 +1,6 @@
+import json
+import os
+import re
 from enum import Enum, auto
 from typing import List, Optional, Union
 from dataclasses import dataclass
@@ -60,14 +63,14 @@ class Sorting:
 
 
 @dataclass
-class Setting:
+class Component:
     type: str
+    queryId: str
 
 
 @dataclass
-class Component:
-    component_type: str
-    setting: Optional[List[Setting]] = None
+class ChartComponent(Component):
+    chartType: str
 
 
 @dataclass
@@ -132,6 +135,10 @@ class Query:
                         operator = "<="
                     elif operator == "EQ":
                         operator = "=="
+                    elif operator == "GT":
+                        operator = ">"
+                    elif operator == "LT":
+                        operator = "<"
                 field_with_agg = condition.field.column
                 if condition.field.aggregation is not None:
                     if isinstance(condition.field.aggregation, SQLFunction) or isinstance(condition.field.aggregation, TimeDimensionGranularity):
@@ -171,5 +178,33 @@ class Query:
 @dataclass
 class SmartQuery:
     queries: List[Query]
-    components: Optional[List[Component]] = None  # use this for of charts
+    id: Optional[str] = None
+    components: Optional[List[Union[ChartComponent, Component]]] = None
     javascript: Optional[List[str]] = None
+
+    @staticmethod
+    def _get_tokens():
+        f = open(os.path.join(os.path.dirname(__file__), "askdata_config", "compression_tokens.json"))
+        comp_tokens = json.load(f)
+        f.close()
+        return comp_tokens
+
+    @staticmethod
+    def compress(smartquery_json: str):
+        comp_tokens = SmartQuery._get_tokens()
+        for token in comp_tokens:
+            extended = token['decode']
+            code = token['code']
+            if extended in smartquery_json:
+                smartquery_json = re.sub(r"\b"+extended+r"\b", code, smartquery_json)
+        return smartquery_json
+
+    @staticmethod
+    def decompress(smartquery_json: str):
+        comp_tokens = SmartQuery._get_tokens()
+        for token in comp_tokens:
+            code = token['code']
+            decode = token['decode']
+            if code in smartquery_json:
+                smartquery_json = re.sub(r"\b"+code+r"\b", decode, smartquery_json)
+        return smartquery_json
